@@ -9,7 +9,6 @@ from typing import Optional
 from funcy import first
 import legion_utils
 from legion_utils import Priority, NotificationMsg
-from typeguard import typechecked
 
 from testudo.config import TaskConfig
 from testudo.log import log
@@ -18,7 +17,6 @@ from testudo.task_manager import task_manager
 HOSTNAME = gethostname()
 
 
-@typechecked
 def report(db: Path, task_config: TaskConfig) -> NotificationMsg:
     with task_manager(db) as tm:
         if recent_failures := list(f for f in tm.get_recent_failures(task_config.task_id)):
@@ -44,7 +42,7 @@ def report(db: Path, task_config: TaskConfig) -> NotificationMsg:
                                ttl=ceil(task_config.legion.reporting_delay_seconds * 2),
                                priority=Priority.ERROR)
 
-@typechecked
+
 def publish_report(db: Path, task_config: TaskConfig) -> Optional[NotificationMsg]:
     rpt = report(db, task_config)
     try:
@@ -58,14 +56,13 @@ def publish_report(db: Path, task_config: TaskConfig) -> Optional[NotificationMs
     return None
 
 
-@typechecked
 def run_reporter(db: Path, task_config: TaskConfig, halt: Event) -> None:
     while 42:
         publish_report(db, task_config)
         if halt.wait(task_config.legion.reporting_delay_seconds):
             return None
 
-@typechecked
+
 def start_reporter_daemon(db: Path, task_config: TaskConfig, halt: Optional[Event] = None) -> Thread:
     reporter_thread = Thread(target=run_reporter,
                              args=(db, task_config, halt),
